==> ses-1.60.0-sources.jar: software/amazon/awscdk/services/ses/ReceiptFilterProps.java <==
package software.amazon.awscdk.services.ses;

/**
 * Construction properties for a ReceiptFilter.
 * <p>
 * EXPERIMENTAL
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.9.0 (build 5c646d5)", date = "2020-08-19T23:25:15.450Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ses.$Module.class, fqn = "@aws-cdk/aws-ses.ReceiptFilterProps")
@software.amazon.jsii.Jsii.Proxy(ReceiptFilterProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface ReceiptFilterProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * The ip address or range to filter.
     * <p>
     * Default: 0.0.0.0/0
     * <p>
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.String getIp() {
        return null;
    }

    /**
     * The policy for the filter.
     * <p>
     * Default: Block
     * <p>
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.ses.ReceiptFilterPolicy getPolicy() {
        return null;
    }

    /**
     * The name for the receipt filter.
     * <p>
     * Default: a CloudFormation generated name
     * <p>
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.String getReceiptFilterName() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link ReceiptFilterProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link ReceiptFilterProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<ReceiptFilterProps> {
        private java.lang.String ip;
        private software.amazon.awscdk.services.ses.ReceiptFilterPolicy policy;
        private java.lang.String receiptFilterName;

        /**
         * Sets the value of {@link ReceiptFilterProps#getIp}
         * @param ip The ip address or range to filter.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder ip(java.lang.String ip) {
            this.ip = ip;
            return this;
        }

        /**
         * Sets the value of {@link ReceiptFilterProps#getPolicy}
         * @param policy The policy for the filter.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder policy(software.amazon.awscdk.services.ses.ReceiptFilterPolicy policy) {
            this.policy = policy;
            return this;
        }

        /**
         * Sets the value of {@link ReceiptFilterProps#getReceiptFilterName}
         * @param receiptFilterName The name for the receipt filter.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder receiptFilterName(java.lang.String receiptFilterName) {
            this.receiptFilterName = receiptFilterName;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link ReceiptFilterProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public ReceiptFilterProps build() {
            return new Jsii$Proxy(ip, policy, receiptFilterName);
        }
    }

    /**
     * An implementation for {@link ReceiptFilterProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements ReceiptFilterProps {
        private final java.lang.String ip;
        private final software.amazon.awscdk.services.ses.ReceiptFilterPolicy policy;
        private final java.lang.String receiptFilterName;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.ip = this.jsiiGet("ip", java.lang.String.class);
            this.policy = this.jsiiGet("policy", software.amazon.awscdk.services.ses.ReceiptFilterPolicy.class);
            this.receiptFilterName = this.jsiiGet("receiptFilterName", java.lang.String.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(final java.lang.String ip, final software.amazon.awscdk.services.ses.ReceiptFilterPolicy policy, final java.lang.String receiptFilterName) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.ip = ip;
            this.policy = policy;
            this.receiptFilterName = receiptFilterName;
        }

        @Override
        public java.lang.String getIp() {
            return this.ip;
        }

        @Override
        public software.amazon.awscdk.services.ses.ReceiptFilterPolicy getPolicy() {
            return this.policy;
        }

        @Override
        public java.lang.String getReceiptFilterName() {
            return this.receiptFilterName;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getIp() != null) {
                data.set("ip", om.valueToTree(this.getIp()));
            }
            if (this.getPolicy() != null) {
                data.set("policy", om.valueToTree(this.getPolicy()));
            }
            if (this.getReceiptFilterName() != null) {
                data.set("receiptFilterName", om.valueToTree(this.getReceiptFilterName()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-ses.ReceiptFilterProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            ReceiptFilterProps.Jsii$Proxy that = (ReceiptFilterProps.Jsii$Proxy) o;

            if (this.ip != null ? !this.ip.equals(that.ip) : that.ip != null) return false;
            if (this.policy != null ? !this.policy.equals(that.policy) : that.policy != null) return false;
            return this.receiptFilterName != null ? this.receiptFilterName.equals(that.receiptFilterName) : that.receiptFilterName == null;
        }

        @Override
        public int hashCode() {
            int result = this.ip != null ? this.ip.hashCode() : 0;
            result = 31 * result + (this.policy != null ? this.policy.hashCode() : 0);
            result = 31 * result + (this.receiptFilterName != null ? this.receiptFilterName.hashCode() : 0);
            return result;
        }
    }
}

==> ses-1.173.0-sources.jar: software/amazon/awscdk/services/ses/ReceiptFilterProps.java <==
package software.amazon.awscdk.services.ses;

/**
 * Construction properties for a ReceiptFilter.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * ReceiptFilter.Builder.create(this, "Filter")
 *         .ip("1.2.3.4/16")
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.67.0 (build 2c027f5)", date = "2022-09-16T18:50:30.642Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ses.$Module.class, fqn = "@aws-cdk/aws-ses.ReceiptFilterProps")
@software.amazon.jsii.Jsii.Proxy(ReceiptFilterProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface ReceiptFilterProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * The ip address or range to filter.
     * <p>
     * Default: 0.0.0.0/0
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getIp() {
        return null;
    }

    /**
     * The policy for the filter.
     * <p>
     * Default: Block
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.ses.ReceiptFilterPolicy getPolicy() {
        return null;
    }

    /**
     * The name for the receipt filter.
     * <p>
     * Default: a CloudFormation generated name
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getReceiptFilterName() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link ReceiptFilterProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link ReceiptFilterProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<ReceiptFilterProps> {
        java.lang.String ip;
        software.amazon.awscdk.services.ses.ReceiptFilterPolicy policy;
        java.lang.String receiptFilterName;

        /**
         * Sets the value of {@link ReceiptFilterProps#getIp}
         * @param ip The ip address or range to filter.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder ip(java.lang.String ip) {
            this.ip = ip;
            return this;
        }

        /**
         * Sets the value of {@link ReceiptFilterProps#getPolicy}
         * @param policy The policy for the filter.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder policy(software.amazon.awscdk.services.ses.ReceiptFilterPolicy policy) {
            this.policy = policy;
            return this;
        }

        /**
         * Sets the value of {@link ReceiptFilterProps#getReceiptFilterName}
         * @param receiptFilterName The name for the receipt filter.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder receiptFilterName(java.lang.String receiptFilterName) {
            this.receiptFilterName = receiptFilterName;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link ReceiptFilterProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public ReceiptFilterProps build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link ReceiptFilterProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements ReceiptFilterProps {
        private final java.lang.String ip;
        private final software.amazon.awscdk.services.ses.ReceiptFilterPolicy policy;
        private final java.lang.String receiptFilterName;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.ip = software.amazon.jsii.Kernel.get(this, "ip", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.policy = software.amazon.jsii.Kernel.get(this, "policy", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.ses.ReceiptFilterPolicy.class));
            this.receiptFilterName = software.amazon.jsii.Kernel.get(this, "receiptFilterName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.ip = builder.ip;
            this.policy = builder.policy;
            this.receiptFilterName = builder.receiptFilterName;
        }

        @Override
        public final java.lang.String getIp() {
            return this.ip;
        }

        @Override
        public final software.amazon.awscdk.services.ses.ReceiptFilterPolicy getPolicy() {
            return this.policy;
        }

        @Override
        public final java.lang.String getReceiptFilterName() {
            return this.receiptFilterName;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getIp() != null) {
                data.set("ip", om.valueToTree(this.getIp()));
            }
            if (this.getPolicy() != null) {
                data.set("policy", om.valueToTree(this.getPolicy()));
            }
            if (this.getReceiptFilterName() != null) {
                data.set("receiptFilterName", om.valueToTree(this.getReceiptFilterName()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-ses.ReceiptFilterProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            ReceiptFilterProps.Jsii$Proxy that = (ReceiptFilterProps.Jsii$Proxy) o;

            if (this.ip != null ? !this.ip.equals(that.ip) : that.ip != null) return false;
            if (this.policy != null ? !this.policy.equals(that.policy) : that.policy != null) return false;
            return this.receiptFilterName != null ? this.receiptFilterName.equals(that.receiptFilterName) : that.receiptFilterName == null;
        }

        @Override
        public final int hashCode() {
            int result = this.ip != null ? this.ip.hashCode() : 0;
            result = 31 * result + (this.policy != null ? this.policy.hashCode() : 0);
            result = 31 * result + (this.receiptFilterName != null ? this.receiptFilterName.hashCode() : 0);
            return result;
        }
    }
}
